@@ -95,6 +95,7 @@ __all__ = (
     "GetTypeResponseTypeDef",
     "GraphqlApiTypeDef",
     "HttpDataSourceConfigTypeDef",
+    "LambdaAuthorizerConfigTypeDef",
     "LambdaConflictHandlerConfigTypeDef",
     "LambdaDataSourceConfigTypeDef",
     "ListApiKeysRequestRequestTypeDef",
@@ -150,6 +151,7 @@ AdditionalAuthenticationProviderTypeDef = TypedDict(
         "authenticationType": AuthenticationTypeType,
         "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
         "userPoolConfig": "CognitoUserPoolConfigTypeDef",
+        "lambdaAuthorizerConfig": "LambdaAuthorizerConfigTypeDef",
     },
     total=False,
 )
@@ -390,6 +392,7 @@ _OptionalCreateGraphqlApiRequestRequestTypeDef = TypedDict(
         "tags": Dict[str, str],
         "additionalAuthenticationProviders": List["AdditionalAuthenticationProviderTypeDef"],
         "xrayEnabled": bool,
+        "lambdaAuthorizerConfig": "LambdaAuthorizerConfigTypeDef",
     },
     total=False,
 )
@@ -758,6 +761,7 @@ GraphqlApiTypeDef = TypedDict(
         "additionalAuthenticationProviders": List["AdditionalAuthenticationProviderTypeDef"],
         "xrayEnabled": bool,
         "wafWebAclArn": str,
+        "lambdaAuthorizerConfig": "LambdaAuthorizerConfigTypeDef",
     },
     total=False,
 )
@@ -771,6 +775,28 @@ HttpDataSourceConfigTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredLambdaAuthorizerConfigTypeDef = TypedDict(
+    "_RequiredLambdaAuthorizerConfigTypeDef",
+    {
+        "authorizerUri": str,
+    },
+)
+_OptionalLambdaAuthorizerConfigTypeDef = TypedDict(
+    "_OptionalLambdaAuthorizerConfigTypeDef",
+    {
+        "authorizerResultTtlInSeconds": int,
+        "identityValidationExpression": str,
+    },
+    total=False,
+)
+
+
+class LambdaAuthorizerConfigTypeDef(
+    _RequiredLambdaAuthorizerConfigTypeDef, _OptionalLambdaAuthorizerConfigTypeDef
+):
+    pass
+
+
 LambdaConflictHandlerConfigTypeDef = TypedDict(
     "LambdaConflictHandlerConfigTypeDef",
     {
@@ -1311,6 +1337,7 @@ _OptionalUpdateGraphqlApiRequestRequestTypeDef = TypedDict(
         "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
         "additionalAuthenticationProviders": List["AdditionalAuthenticationProviderTypeDef"],
         "xrayEnabled": bool,
+        "lambdaAuthorizerConfig": "LambdaAuthorizerConfigTypeDef",
     },
     total=False,
 )
